@@ -52,10 +52,7 @@ Q_IMPORT_PLUGIN(qgif)
 
 int main(int argc, char **argv)
 {
-    // Setup build information and version string
-  # include "version.gen"
-    buildinfo.append(QString(",%1,%2").arg(__DATE__, __TIME__));
-    Quassel::setupBuildInfo(buildinfo);
+    Quassel::setupBuildInfo();
     QCoreApplication::setApplicationName(Quassel::buildInfo().applicationName);
     QCoreApplication::setOrganizationName(Quassel::buildInfo().organizationName);
     QCoreApplication::setOrganizationDomain(Quassel::buildInfo().organizationDomain);
@@ -65,6 +62,26 @@ int main(int argc, char **argv)
     QApplication::setGraphicsSystem("raster");
 #endif
 
+    // We need to explicitly initialize the required resources when linking statically
+#ifndef BUILD_QTUI
+    Q_INIT_RESOURCE(sql);
+#endif
+#ifndef BUILD_CORE
+    Q_INIT_RESOURCE(pics); // always in a resource, for now
+#endif
+
+#ifdef EMBED_DATA
+    Q_INIT_RESOURCE(i18n);
+# ifndef BUILD_CORE
+    Q_INIT_RESOURCE(data);
+    Q_INIT_RESOURCE(hicolor);
+    Q_INIT_RESOURCE(oxygen);
+#   ifdef WITH_OXYGEN
+    Q_INIT_RESOURCE(oxygen_kde);
+#   endif
+# endif
+#endif
+
     AbstractCliParser *cliParser;
 
 #ifdef HAVE_KDE
@@ -123,6 +140,7 @@ int main(int argc, char **argv)
 #ifdef HAVE_SSL
     cliParser->addSwitch("require-ssl", 0, "Require SSL for client connections");
 #endif
+    cliParser->addSwitch("enable-experimental-dcc", 0, "Enable highly experimental and unfinished support for CTCP DCC (DANGEROUS)");
 #endif
 
 #ifdef HAVE_KDE
