@@ -213,10 +213,6 @@ public :
     inline bool autoAwayActive() const { return _autoAwayActive; }
     inline void setAutoAwayActive(bool active) { _autoAwayActive = active; }
 
-    static QStringList presetNetworks(bool onlyDefault = false);
-    static QStringList presetDefaultChannels(const QString &networkName);
-    static NetworkInfo networkInfoFromPreset(const QString &networkName);
-
 public slots:
     void setNetworkName(const QString &networkName);
     void setCurrentServer(const QString &currentServer);
@@ -372,8 +368,6 @@ private:
 
     bool _autoAwayActive; // when this is active handle305 and handle306 don't trigger any output
 
-    static QString _networksIniPath;
-
     friend class IrcUser;
     friend class IrcChannel;
 };
