@@ -80,7 +80,7 @@ void ChatView::init(MessageFilter *filter)
     setScene(_scene);
 
     connect(verticalScrollBar(), SIGNAL(valueChanged(int)), this, SLOT(verticalScrollbarChanged(int)));
-    _lastScrollbarPos = verticalScrollBar()->value();
+    _lastScrollbarPos = verticalScrollBar()->maximum();
 
     connect(Client::networkModel(), SIGNAL(markerLineSet(BufferId, MsgId)), SLOT(markerLineSet(BufferId, MsgId)));
 
@@ -126,18 +126,26 @@ bool ChatView::event(QEvent *event)
 
 void ChatView::resizeEvent(QResizeEvent *event)
 {
+    // if view is currently scrolled to bottom, we want it that way after resizing
+    bool atBottom = (_lastScrollbarPos == verticalScrollBar()->maximum());
+
     QGraphicsView::resizeEvent(event);
 
-    // FIXME: do we really need to scroll down on resize?
+    // if scrolling to bottom, do it immediately.
+    if(atBottom)
+    {
+        // we can reduce viewport updates if we scroll to the bottom allready at the beginning
+        verticalScrollBar()->setValue(verticalScrollBar()->maximum());
+    }
 
-    // we can reduce viewport updates if we scroll to the bottom allready at the beginning
-    verticalScrollBar()->setValue(verticalScrollBar()->maximum());
     scene()->updateForViewport(viewport()->width(), viewport()->height());
     adjustSceneRect();
 
-    _lastScrollbarPos = verticalScrollBar()->maximum();
-    verticalScrollBar()->setValue(verticalScrollBar()->maximum());
-
+    if(atBottom)
+    {
+        _lastScrollbarPos = verticalScrollBar()->maximum();
+        verticalScrollBar()->setValue(verticalScrollBar()->maximum());
+    }
     checkChatLineCaches();
 }
 
