@@ -301,7 +301,7 @@ void MultiLineEdit::keyPressEvent(QKeyEvent *event)
     if (event == QKeySequence::InsertLineSeparator) {
 #else
 
-# ifdef Q_WS_MAC
+# ifdef Q_OS_MAC
     if ((event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter) && event->modifiers() & Qt::META) {
 # else
     if ((event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter) && event->modifiers() & Qt::SHIFT) {
@@ -718,7 +718,11 @@ void MultiLineEdit::on_textChanged()
                 QString msg = tr("Do you really want to paste %n line(s)?", "", lines.count());
                 msg += "<p>";
                 for (int i = 0; i < 4; i++) {
+#if QT_VERSION < 0x050000
                     msg += Qt::escape(lines[i].left(40));
+#else
+                    msg += lines[i].left(40).toHtmlEscaped();
+#endif
                     if (lines[i].count() > 40)
                         msg += "...";
                     msg += "<br />";
@@ -726,7 +730,7 @@ void MultiLineEdit::on_textChanged()
                 msg += "...</p>";
                 QMessageBox question(QMessageBox::NoIcon, tr("Paste Protection"), msg, QMessageBox::Yes|QMessageBox::No);
                 question.setDefaultButton(QMessageBox::No);
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
                 question.setWindowFlags(question.windowFlags() | Qt::Sheet);
 #endif
                 if (question.exec() != QMessageBox::Yes)
